==> MuSE-0.4.1.tar.gz: MuSE-0.4.1/get_xaudio.sh <==
#!/bin/sh

if [ ! -n "$1" ]; then

echo "--------------------------------------------------------------"
echo "specify where to find the xaudio sdk file on the command line!"
echo "if you did'nt downloaded it yet have a look on:"
echo "http://www.xaudio.com/developers/"
echo "for further instructions refer to the README file"
echo "--------------------------------------------------------------"
exit 0
fi

if [ ! -r $1 -o ! -f $1 ] ;

then
echo "------------------------------------"
echo "can't find specified xaudio sdk $1"
echo "pliz download it from www.xaudio.com"
echo "------------------------------------"
exit 0
else

echo "ok! xaudio sdk found. proceeding to extraction..."

tar xfz $1 \
	xasdk-*.x86-unknown-linux-glibc/lib/libxaudio.a	\
	xasdk-*.x86-unknown-linux-glibc/include/xaudio.h	\
	xasdk-*.x86-unknown-linux-glibc/include/decoder.h	\
	xasdk-*.x86-unknown-linux-glibc/include/mpeg_codec.h	\
	xasdk-*.x86-unknown-linux-glibc/include/audio_output.h	\
	xasdk-*.x86-unknown-linux-glibc/include/file_input.h	\
	xasdk-*.x86-unknown-linux-glibc/include/file_output.h	\
	xasdk-*.x86-unknown-linux-glibc/include/memory_input.h	\
	xasdk-*.x86-unknown-linux-glibc/include/stream_input.h	\
	xasdk-*.x86-unknown-linux-glibc/include/player.h	\
	xasdk-*.x86-unknown-linux-glibc/include/control.h	\
	xasdk-*.x86-unknown-linux-glibc/include/control_pipe.h	\
	xasdk-*.x86-unknown-linux-glibc/include/properties.h
ln -s xasdk-*.x86-unknown-linux-glibc xaudio

echo "done! now you can safely proceed with ./configure and make"
exit 1
fi

echo "--------------------------------------------------------------"
echo "specify where to find the xaudio sdk file on the command line!"
echo "if you did'nt downloaded it yet have a look on www.xaudio.com"
echo "for further instructions refer to the README file"
echo "--------------------------------------------------------------"
exit 0
fi

==> MuSE-0.5.2.tar.gz: MuSE-0.5.2/get_xaudio.sh <==
#!/bin/sh

if [ ! -n "$1" ]; then

echo "--------------------------------------------------------------"
echo "specify where to find the xaudio sdk file on the command line!"
echo "if you did'nt downloaded it yet have a look on:"
echo "http://www.xaudio.com/developers/"
echo "for further instructions refer to the README file"
echo "--------------------------------------------------------------"
exit 1
fi

if [ ! -r $1 -o ! -f $1 ] ;

then
echo "------------------------------------"
echo "can't find specified xaudio sdk $1"
echo "pliz download it from www.xaudio.com"
echo "------------------------------------"
exit 1
else

echo "ok! xaudio sdk found. proceeding to extraction..."

tar xfz $1 \
	xasdk-*.x86-unknown-linux-glibc/lib/libxaudio.a	\
	xasdk-*.x86-unknown-linux-glibc/include/xaudio.h	\
	xasdk-*.x86-unknown-linux-glibc/include/decoder.h	\
	xasdk-*.x86-unknown-linux-glibc/include/mpeg_codec.h	\
	xasdk-*.x86-unknown-linux-glibc/include/audio_output.h	\
	xasdk-*.x86-unknown-linux-glibc/include/file_input.h	\
	xasdk-*.x86-unknown-linux-glibc/include/file_output.h	\
	xasdk-*.x86-unknown-linux-glibc/include/memory_input.h	\
	xasdk-*.x86-unknown-linux-glibc/include/stream_input.h	\
	xasdk-*.x86-unknown-linux-glibc/include/player.h	\
	xasdk-*.x86-unknown-linux-glibc/include/control.h	\
	xasdk-*.x86-unknown-linux-glibc/include/control_pipe.h	\
	xasdk-*.x86-unknown-linux-glibc/include/properties.h
ln -sf xasdk-*.x86-unknown-linux-glibc xaudio

echo "done!"
exit 0
fi

echo "--------------------------------------------------------------"
echo "specify where to find the xaudio sdk file on the command line!"
echo "if you did'nt downloaded it yet have a look on www.xaudio.com"
echo "for further instructions refer to the README file"
echo "--------------------------------------------------------------"
exit 1
fi
